/*
 *  /MathJax/localization/da/MathMenu.js
 *
 *  Copyright (c) 2009-2015 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("da","MathMenu",{version:"2.6.0",isLoaded:true,strings:{Show:"Vis matematik som",MathMLcode:"MathML kode",OriginalMathML:"Oprindelige MathML",TeXCommands:"TeX kommandoer",AsciiMathInput:"AsciiMathML input",Original:"Oprindelige format",ErrorMessage:"Fejlmeddelelse",Annotation:"Anm\u00E6rkning",TeX:"TeX",StarMath:"StarMath",Maple:"Maple",ContentMathML:"Content MathML",OpenMath:"OpenMath",texHints:"Vis TeX hints i MathML",Settings:"Matematikindstillinger",ZoomTrigger:"Zoom udl\u00F8ser",Hover:"Hover",Click:"Klik",DoubleClick:"Dobbeltklik",NoZoom:"Ingen zoom",TriggerRequires:"Udl\u00F8ser kr\u00E6ver:",Option:"Option",Alt:"Alt",Command:"Command",Control:"Ctrl",Shift:"Shift",ZoomFactor:"Zoomfaktor",Renderer:"Matematik renderer",MPHandles:"Lad MathPlayer h\u00E5ndtere:",MenuEvents:"Menubegivenheder",MouseEvents:"Musebegivenheder",MenuAndMouse:"Muse- og menu-begivenheder",FontPrefs:"Skrifttype indstillinger",ForHTMLCSS:"For HTML-CSS:",Auto:"Auto",TeXLocal:"TeX (lokal)",TeXWeb:"TeX (web)",TeXImage:"TeX (billede)",STIXLocal:"STIX (lokal)",STIXWeb:"STIX (web)",AsanaMathWeb:"Asana Math (web)",GyrePagellaWeb:"Gyre Pagella (web)",GyreTermesWeb:"Gyre Termes (web)",LatinModernWeb:"Latin Modern (web)",NeoEulerWeb:"Neo Euler (web)",ContextMenu:"Kontekstuelle menu",Browser:"Browser",Scale:"Skaler alt matematik...",Discoverable:"Fremh\u00E6v ved hover",Locale:"Sprog",LoadLocale:"Indl\u00E6ser fra URL...",About:"Om MathJax",Help:"MathJax hj\u00E6lp",localTeXfonts:"ved hj\u00E6lp af lokale TeX skrifttyper",webTeXfonts:"ved hj\u00E6lp af TeX webskrifttyper",imagefonts:"ved hj\u00E6lp af billede skrifttyper",localSTIXfonts:"ved hj\u00E6lp af lokale STIX skrifttyper",webSVGfonts:"ved hj\u00E6lp af web SVG skrifttyper",genericfonts:"ved hj\u00E6lp af generiske Unicode-skrifttyper",wofforotffonts:"WOFF eller OTF skrifttyper",eotffonts:"EOT skrifttyper",svgfonts:"SVG skrifttyper",WebkitNativeMMLWarning:"Din browser synes ikke at have indbygget st\u00F8tte til MathML, s\u00E5 et skift til MathML output kan for\u00E5rsage at matematik p\u00E5 siden bliver ul\u00E6selig",MSIENativeMMLWarning:"Internet Explorer kr\u00E6ver MathPlayer plugin for at kunne behandle MathML output.",OperaNativeMMLWarning:"Operas underst\u00F8ttelse af MathML er begr\u00E6nset, s\u00E5 et skift til MathML output kan for\u00E5rsage at nogle udtryk bliver vist d\u00E5rligt.",SafariNativeMMLWarning:"Din browsers indbyggede MathML underst\u00F8tter ikke alle de funktioner, der anvendes af MathJax, s\u00E5 nogle udtryk gengives muligvis ikke korrekt.",FirefoxNativeMMLWarning:"Din browsers indbyggede MathML underst\u00F8tter ikke alle de funktioner, der anvendes af MathJax, s\u00E5 nogle udtryk gengives muligvis ikke korrekt.",MSIESVGWarning:"SVG er ikke implementeret i Internet Explorer f\u00F8r IE9 eller n\u00E5r der emuleres IE8 eller nedefter. Et skifte til SVG-output vil for\u00E5rsage at matematik ikke vises korrekt.",LoadURL:"Indl\u00E6s overs\u00E6ttelsesdata fra denne URL:",BadURL:"URL-adressen skal v\u00E6re for en JavaScript-fil, der definerer MathJax overs\u00E6ttelsesdata. JavaScript filnavne skal afsluttes med '.js'",BadData:"Kunne ikke indl\u00E6se overs\u00E6ttelsesdata fra %1",SwitchAnyway:"Skift renderer alligevel?\n\n(Tryk p\u00E5 OK for at skifte, ANNULLER for at forts\u00E6tte med den nuv\u00E6rende renderer)",ScaleMath:"Skal\u00E9r alt matematik (sammenlignet med omgivende tekst) med",NonZeroScale:"Skaleringen m\u00E5 ikke v\u00E6re nul",PercentScale:"Skaleringen skal v\u00E6re en procentsats (for eksempel 120%%)",IE8warning:"Dette vil deaktivere MathJax funktionerne menu og zoom, men du kan ogs\u00E5 Alt-klikke p\u00E5 et udtryk for at f\u00E5 MathJax menuen i stedet.\n\nVil du virkelig \u00E6ndre indstillingerne for MathPlayer?",IE9warning:"Den kontekstuelle MathJax menu vil blive deaktiveret, men du kan Alt-klikke p\u00E5 et udtryk for at f\u00E5 MathJax menuen i stedet.",NoOriginalForm:"Ingen oprindelig form, til r\u00E5dighed",Close:"Luk",EqSource:"MathJax ligningskilde"}});MathJax.Ajax.loadComplete("[MathJax]/localization/da/MathMenu.js");
